CustomFormW class

Inheritance

Constructors

CustomFormW({Key? key, required List<CustomTextField> children, GlobalKey<FormState>? formKey, String buttonText = 'Submit', Color buttonColor = Colors.blue, TextStyle buttonTextStyle = const TextStyle(color: Colors.white), dynamic onSubmit()?, bool showButton = true, double spacing = 10, String? validationSnackBarText, bool showValidationSnackBar = true, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 16), double spaceHeaders = 5, ShapeBorder? buttonShape})
const

Properties

buttonColor Color
final
buttonShape ShapeBorder?
final
buttonText String
final
buttonTextStyle TextStyle
final
children List<CustomTextField>
final
formKey GlobalKey<FormState>?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSubmit → dynamic Function()?
final
padding EdgeInsetsGeometry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showButton bool
final
showValidationSnackBar bool
final
spaceHeaders double
final
spacing double
final
validationSnackBarText String?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CustomFormW>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited